# DelphaDBManagement

Management API for Delpha to work around Data inside the Cassandra Cluster

This repository is python based yet, to be open to other languages (Java, JavaScript, ...)
Module to handle DB Managmenet on our Cassandra Cluster.


![title](docs/images/db1.png)

# Security Objectives

Need a really secure way to handle data : 

**Private Keys** will be generated by Delpha only and will be stored inside an authentication table inside Cassandra. Users will need to match a given private key to access the DBMS. This key will be bound to the dedicated organisation, and only one Private Key will be tagged as Admin and unlock all the DBMS access.

![title](docs/images/db3.png)

![title](docs/images/db2.png)



# Installation
### Requirements
**Python** : >3.8

### Install Dependencies

Common

```bash
pip install -r requirements.txt
```

### Salesforce Manager

Salesforce Data Manager using Salesforce API.

- Parameter : instance_name: Salesforce Instance name
- Parameter : client_id: Consumer ID for authorized app
- Parameter : client_secret: Consumer Secret for authorized app
- Parameter : username: usernam to login to Instance of Salesforce
- Parameter : param password: password to login to Instance of Salesforce
- Parameter : param security_token: User's security token


```python
sf_manager = SalesforceManager(instance_name, consumer_key, consumer_secret, salesforce_username, salesforce_pwd, personnal_token)
sf_manager.help()
res, size = sf_manager.query("SELECT Name from Contact")
```


### Cassandra Manager

Cassandra Database manager : **CassandraManager**.

- Parameter : username: String Cassandra username to connect
- Parameter : password: String password username to connect
- Parameter : pem_file_path: String path of the .pem file to use for 2FA connection
- Parameter : key_space: String session keyspace to set for the Cluster

```python
cass_cluster = CassandraManager(username, password, key_file_path, "delpha_actions")
cass_cluster.execute("SELECT * FROM actions_conv_by_user").all()
```


Dictionnary part of Cassandra Database manager : **DictionaryManager**.

```python
manager = DictionaryManager(cass_cluster)
manager.list_tables
```
~~~python=1
['keyspace1', 'keyspace2', ...]
~~~



### AWS Manager

Delpha AWS data Handler (AppFlows) : **AWSManager**.

- Parameter : key: String AWS key
- Parameter : secret: String AWS secret
- Parameter : flow_type: String Flow type to handle ['contact', 'account']
- Parameter : region: String AWS region 

```python
handler = AWSManager(aws_key_id, aws_secret, 'contact') #Setup contact Flow (contact dataset)
df = handler.get_flow_parquet_data()
```


```python
flow_status, flow_last_execution_record = handler.start_flow(flow_name) #Start flow on AWS side

handler.ensure_spark_format(flow_name) #Check if data is in right format (.parquet)

handler.get_last_flow_id(flow_name) #Get last folder Name in bucket for specific flow.
```



### How to - Pip publish package

```shell
python setup.py sdist bdist_wheel
twine upload dist/*
```

## License
